@@ -5,38 +5,26 @@ require "set"
 
 class TestCollapse < LoaderTest
   test "top-level directories can be collapsed" do
-    files = [["foo/bar/x.rb", "Bar::X = true"]]
-    with_files(files) do
-      loader.push_dir(".")
-      loader.collapse("foo")
-      loader.setup
-
+    files = [["collapsed/bar/x.rb", "Bar::X = true"]]
+    with_setup(files) do
       assert Bar::X
     end
   end
 
   test "collapsed directories are ignored as namespaces" do
-    files = [["foo/bar/x.rb", "Foo::X = true"]]
-    with_files(files) do
-      loader.push_dir(".")
-      loader.collapse("foo/bar")
-      loader.setup
-
+    files = [["foo/collapsed/x.rb", "Foo::X = true"]]
+    with_setup(files) do
       assert Foo::X
     end
   end
 
   test "collapsed directories are ignored as explicit namespaces" do
     files = [
-      ["foo.rb", "Foo = true"],
-      ["foo/x.rb", "X = true"]
+      ["collapsed.rb", "Collapsed = true"],
+      ["collapsed/x.rb", "X = true"]
     ]
-    with_files(files) do
-      loader.push_dir(".")
-      loader.collapse("foo")
-      loader.setup
-
-      assert Foo
+    with_setup(files) do
+      assert Collapsed
       assert X
     end
   end
@@ -114,7 +102,7 @@ class TestCollapse < LoaderTest
     end
   end
 
-  test "collapse directories are recomputed on reload" do
+  test "collapse glob patterns are recomputed on reload" do
     files = [["foo/bar/x.rb", "Foo::X = true"]]
     with_files(files) do
       loader.push_dir(".")
@@ -136,27 +124,19 @@ class TestCollapse < LoaderTest
 
   test "collapse directories are honored when eager loading" do
     $collapse_honored_when_eager_loading = false
-    files = [["foo/bar/x.rb", "Foo::X = true; $collapse_honored_when_eager_loading = true"]]
-    with_files(files) do
-      loader.push_dir(".")
-      loader.collapse("foo/bar")
-      loader.setup
+    files = [["foo/collapsed/x.rb", "Foo::X = true"]]
+    with_setup(files) do
       loader.eager_load
-
-      assert $collapse_honored_when_eager_loading
+      assert required?(files)
     end
   end
 
   test "collapsed top-level directories are eager loaded too" do
     $collapse_honored_when_eager_loading = false
-    files = [["foo/bar/x.rb", "Bar::X = true; $collapse_honored_when_eager_loading = true"]]
-    with_files(files) do
-      loader.push_dir(".")
-      loader.collapse("foo")
-      loader.setup
+    files = [["collapsed/bar/x.rb", "Bar::X = true"]]
+    with_setup(files) do
       loader.eager_load
-
-      assert $collapse_honored_when_eager_loading
+      assert required?(files)
     end
   end
 end
