@@ -60,6 +60,16 @@ class TestConflictingDirectory < LoaderTest
     assert loader.push_dir(dir)
   end
 
+  test "does not raise if a second existing loader ignores the directory (dir)" do
+    # Ensure this loader is loaded
+    existing_loader
+    second_existing_loader = new_loader(setup: false)
+    second_existing_loader.push_dir(parent)
+    second_existing_loader.ignore(dir)
+
+    assert loader.push_dir(dir)
+  end
+
   test "does not raise if an existing loader ignores the directory (glob pattern)" do
     existing_loader.push_dir(parent)
     existing_loader.ignore("#{parent}/*")
