@@ -133,6 +133,17 @@ class TestLogging < LoaderTest
     end
   end
 
+  test "logs failed autoloads, provided the require call succeeded" do
+    files = [["x.rb", ""]]
+    with_files(files) do
+      assert_logged(/expected file #{File.expand_path("x.rb")} to define constant X, but didn't/) do
+        loader.push_dir(".")
+        loader.setup
+        assert_raises(Zeitwerk::NameError) { X }
+      end
+    end
+  end
+
   test "logs autoload configured for directories" do
     files = [["admin/user.rb", "class Admin::User; end"]]
     with_files(files) do
@@ -180,25 +191,7 @@ class TestLogging < LoaderTest
     end
   end
 
-  test "logs when eager loading starts" do
-    files = [["x.rb", "X = true"]]
-    with_files(files) do
-      assert_logged(/eager load start/) do
-        loader.eager_load
-      end
-    end
-  end
-
-  test "logs when eager loading ends" do
-    files = [["x.rb", "X = true"]]
-    with_files(files) do
-      assert_logged(/eager load end/) do
-        loader.eager_load
-      end
-    end
-  end
-
-  test "eager loading skips files that would map to already loaded constants" do
+  test "logs files shadowed by already defined constants" do
     on_teardown { remove_const :X }
 
     ::X = 1
@@ -210,4 +203,50 @@ class TestLogging < LoaderTest
       end
     end
   end
+
+  test "logs directories being ignored because they have no Ruby files" do
+    files = [["tasks/foo.rake", ""]]
+    with_files(files) do
+      assert_logged(%r{directory .*?/tasks is ignored because it has no Ruby files}) do
+        loader.push_dir(".")
+        loader.setup
+      end
+    end
+  end
+
+  test "logs when eager loading a directory starts" do
+    with_files([]) do
+      assert_logged(%r(eager load directory #{Dir.pwd} start)) do
+        loader.push_dir(".")
+        loader.setup
+        loader.eager_load_dir(".")
+      end
+    end
+  end
+
+  test "logs when eager loading a directory ends" do
+    with_files([]) do
+      assert_logged(%r(eager load directory #{Dir.pwd} end)) do
+        loader.push_dir(".")
+        loader.setup
+        loader.eager_load_dir(".")
+      end
+    end
+  end
+
+  test "logs when eager loading starts" do
+    with_setup do
+      assert_logged(/eager load start/) do
+        loader.eager_load
+      end
+    end
+  end
+
+  test "logs when eager loading ends" do
+    with_setup do
+      assert_logged(/eager load end/) do
+        loader.eager_load
+      end
+    end
+  end
 end
