@@ -69,28 +69,6 @@ class TestRubyCompatibility < LoaderTest
     end
   end
 
-  # Zeitwerk has to be called as soon as explicit namespaces are defined, to be
-  # able to configure autoloads for their children before the class or module
-  # body is interpreted. If explicit namespaces are found, Zeitwerk sets a trace
-  # point on the :class event with that purpose.
-  #
-  # This is key because the body of explicit namespaces could reference child
-  # constants at the top-level. Mixins are a common use case.
-  test "TracePoint emits :class events" do
-    on_teardown do
-      @tp.disable
-      remove_const :C, from: self.class
-    end
-
-    called = false
-
-    @tp = TracePoint.new(:class) { called = true }
-    @tp.enable
-
-    class C; end
-    assert called
-  end
-
   # We configure autoloads on directories to autovivify modules on demand, and
   # lazily descend to set autoloads for their children. This is more efficient,
   # specially for large code bases.
@@ -157,6 +135,15 @@ class TestRubyCompatibility < LoaderTest
     end
   end
 
+  # We delegate constant name validation to Module#const_defined?.
+  test "const_defined? raises NameError for invalid cnames" do
+    error = assert_raises ::NameError do
+      Module.new.const_defined?("Foo-Bar", false)
+    end
+
+    assert_includes error.message, "wrong constant name Foo-Bar"
+  end
+
   # Unloading removes autoloads by calling remove_const. It is convenient that
   # remove_const does not execute the autoload because it would be surprising,
   # and slower, that those unused files got loaded precisely while unloading.
@@ -206,7 +193,7 @@ class TestRubyCompatibility < LoaderTest
   end
 
   # This edge case justifies the need for the inceptions collection in the
-  # registry. See Zeitwerk::Registry.inceptions.
+  # registry.
   test "an autoload on yourself is ignored" do
     files = [["foo.rb", <<-EOS]]
       Object.autoload(:Foo, __FILE__)
@@ -252,47 +239,6 @@ class TestRubyCompatibility < LoaderTest
     end
   end
 
-  # This is why we issue a namespace_dirs.delete call in the tracer block, to
-  # ignore events triggered by reopenings.
-  test "tracing :class calls you back on creation and on reopening" do
-    on_teardown do
-      @tracer.disable
-      remove_const :C, from: self.class
-      remove_const :M, from: self.class
-    end
-
-    traced = []
-    @tracer = TracePoint.trace(:class) do |tp|
-      traced << tp.self
-    end
-
-    2.times do
-      class C; end
-      module M; end
-    end
-
-    assert_equal [C, M, C, M], traced
-  end
-
-  # Computing hash codes is costly and we want the tracer to be as efficient as
-  # possible. The TP callback doesn't short-circuit anonymous classes/modules
-  # because Class.new/Module.new do not trigger the :class event. We leverage
-  # this property to save a nil? call.
-  #
-  # However, if that changes in future versions of Ruby, this test would tell us
-  # and we could revisit the callback implementation.
-  test "trace points on the :class events don't get called on Class.new and Module.new" do
-    on_teardown { @tracer.disable }
-
-    $tracer_for_anonymous_class_and_modules_called = false
-    @tracer = TracePoint.trace(:class) { $tracer_for_anonymous_class_and_modules_called = true }
-
-    Class.new
-    Module.new
-
-    assert !$tracer_for_anonymous_class_and_modules_called
-  end
-
   # If the user issues a require call with a Pathname object for a path that is
   # autoloadable, we are still able to intercept it because $LOADED_FEATURES
   # stores it as a string and loader_for is able to find its loader. During
@@ -319,12 +265,15 @@ class TestRubyCompatibility < LoaderTest
   # This allows Zeitwerk to be thread-safe on regular file autoloads. Module
   # autovivification is custom, has its own test.
   test "autoloads and constant references are synchronized" do
+    skip 'https://github.com/oracle/truffleruby/issues/2431' if RUBY_ENGINE == 'truffleruby'
+
     $ensure_M_is_autoloaded_by_the_thread = Queue.new
 
     files = [["m.rb", <<-EOS]]
+      $ensure_M_is_autoloaded_by_the_thread.pop()
+
       module M
-        $ensure_M_is_autoloaded_by_the_thread << true
-        sleep 0.5
+        sleep 1
 
         def self.works?
           true
@@ -332,9 +281,14 @@ class TestRubyCompatibility < LoaderTest
       end
     EOS
     with_setup(files) do
-      t = Thread.new { M }
-      $ensure_M_is_autoloaded_by_the_thread.pop()
-      assert M.works?
+      t = Thread.new do
+        $ensure_M_is_autoloaded_by_the_thread << true
+        M
+      end
+
+      sleep 0.5 # Let the thread hit the sleep in m.rb.
+      assert M.works? # this should block until the thread has finished autoloading
+
       t.join
     end
   end
