@@ -5,34 +5,32 @@ require "test_helper"
 class TestUnregister < LoaderTest
   test "unregister removes the loader from internal state" do
     loader1 = Zeitwerk::Loader.new
+    cref1 = Zeitwerk::Cref.new(Object, :"dummy1")
     registry = Zeitwerk::Registry
-    registry.register_loader(loader1)
+    registry.loaders.register(loader1)
     registry.gem_loaders_by_root_file["dummy1"] = loader1
-    registry.register_autoload(loader1, "dummy1")
-    registry.register_inception("dummy1", "dummy1", loader1)
-    Zeitwerk::ExplicitNamespace.__register("dummy1", loader1)
+    registry.autoloads.register("dummy1", loader1)
+    registry.explicit_namespaces.register(cref1, loader1)
 
     loader2 = Zeitwerk::Loader.new
+    cref2 = Zeitwerk::Cref.new(Object, :"dummy2")
     registry = Zeitwerk::Registry
-    registry.register_loader(loader2)
+    registry.loaders.register(loader2)
     registry.gem_loaders_by_root_file["dummy2"] = loader2
-    registry.register_autoload(loader2, "dummy2")
-    registry.register_inception("dummy2", "dummy2", loader2)
-    Zeitwerk::ExplicitNamespace.__register("dummy2", loader2)
+    registry.autoloads.register("dummy2", loader2)
+    registry.explicit_namespaces.register(cref2, loader2)
 
     loader1.unregister
 
-    assert !registry.loaders.include?(loader1)
+    assert !registry.loaders.registered?(loader1)
     assert !registry.gem_loaders_by_root_file.values.include?(loader1)
-    assert !registry.autoloads.values.include?(loader1)
-    assert !registry.inceptions.values.any? {|_, l| l == loader1}
-    assert !Zeitwerk::ExplicitNamespace.send(:cpaths).values.include?(loader1)
+    assert !registry.autoloads.registered?("dummy1")
+    assert !registry.explicit_namespaces.registered?(cref1)
 
-    assert registry.loaders.include?(loader2)
+    assert registry.loaders.registered?(loader2)
     assert registry.gem_loaders_by_root_file.values.include?(loader2)
-    assert registry.autoloads.values.include?(loader2)
-    assert registry.inceptions.values.any? {|_, l| l == loader2}
-    assert Zeitwerk::ExplicitNamespace.send(:cpaths).values.include?(loader2)
+    assert registry.autoloads.registered?("dummy2")
+    assert registry.explicit_namespaces.registered?(cref2) == loader2
   end
 
   test 'with_loader yields and unregisters' do
