@@ -42,8 +42,7 @@ class LoaderTest < Minitest::Test
   end
 
   def reset_explicit_namespace
-    Zeitwerk::ExplicitNamespace.send(:cpaths).clear
-    Zeitwerk::ExplicitNamespace.send(:tracer).disable
+    Zeitwerk::Registry.explicit_namespaces.clear
   end
 
   def teardown
@@ -63,7 +62,11 @@ class LoaderTest < Minitest::Test
     Dir.chdir(TMP_DIR) do
       files.each do |fname, contents|
         FileUtils.mkdir_p(File.dirname(fname))
-        File.write(fname, contents)
+        if contents
+          File.write(fname, contents)
+        else
+          FileUtils.touch(fname)
+        end
       end
       yield
     end
